<?php
namespace Drupal\http_client_log\Logger;

use Drupal\Core\DependencyInjection\DependencySerializationTrait;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\Core\Queue\RequeueException;
use Elastica\Exception\ResponseException;
use Psr\Log\LoggerInterface;

class Logger implements LoggerInterface {
  use RfcLoggerTrait;
  use DependencySerializationTrait;
  /**
   * {@inheritdoc}
   */
  public function log($level, $message, array $context = []) {
    /** @var \GuzzleHttp\Psr7\Request $request */
    $request = $context['request'];
    /** @var \GuzzleHttp\Psr7\Response $response */
    $response = $context['response'];
    try {
      foreach ($request->getHeaders() as $req_k => $req_v) {
        $request_headers[] = $req_k . ': ' . implode('|', $req_v);
      }
      foreach ($response->getHeaders() as $res_k => $res_v) {
        $response_headers[] = $res_k . ': ' . implode('|', $res_v);
      }
      $entity = \Drupal::entityTypeManager()
        ->getStorage('http_client_log')
        ->create([
          'type' => 'http_client_log',
          'request_http_method' => $request->getMethod(),
          'request_url' => $request->getUri(),
          'request_headers' => implode( "\r\n", $request_headers),
          'request_payload' => $request->getBody(),
          'response_status_code' => $response->getStatusCode(),
          'response_reason_phrase' => $response->getReasonPhrase(),
          'response_headers' => implode( "\r\n", $response_headers),
          'response_body' => $response->getBody()->getContents(),
        ]);
      $entity->save();
    } catch (RequeueException $e) {
      $entity = \Drupal::entityTypeManager()
        ->getStorage('http_client_log')
        ->create([
          'type' => 'http_client_log',
          'request_http_method' => $request->getMethod(),
          'request_url' => $request->getUri(),
          'request_payload' => $request->getBody(),
          'response_status_code' => $response->getStatusCode(),
          'response_reason_phrase' => $response->getReasonPhrase(),
          'errors' => $e->getMessage(),
        ]);
      $entity->save();
    } catch (ResponseException $e) {
      $entity = \Drupal::entityTypeManager()
        ->getStorage('http_client_log')
        ->create([
          'type' => 'http_client_log',
          'request_http_method' => $request->getMethod(),
          'request_url' => $request->getUri(),
          'request_payload' => $request->getBody(),
          'response_status_code' => $response->getStatusCode(),
          'response_reason_phrase' => $response->getReasonPhrase(),
          'errors' => $e->getMessage(),
        ]);
      $entity->save();
    }
  }
}

